Balance

Struct Balance 

pub struct Balance { /* private fields */ }
A signed balance of assets, to represent a balance with negative values such as the results of a transaction from the perspective of a wallet.

Implementations

Source

impl Balance

pub fn to_json(&self) -> Result<JsValue, Error>

Convert the balance to a JsValue for serialization

Note: the amounts are strings since JSON.stringify cannot handle BigInts. Use entries() to get the raw data.

pub fn entries(&self) -> Result<JsValue, Error>

Returns the balance as an array of [key, value] pairs.

pub fn to_string_js(&self) -> String

Return the string representation of the balance.