pub struct Balance { /* private fields */ }Expand description
A signed balance of assets, to represent a balance with negative values such as the results of a transaction from the perspective of a wallet.
Implementations
Sourceimpl Balance
impl Balance
Sourcepub fn to_json(&self) -> Result<JsValue, Error>
pub fn to_json(&self) -> Result<JsValue, Error>
Convert the balance to a JsValue for serialization
Note: the amounts are strings since JSON.stringify cannot handle BigInts.
Use entries() to get the raw data.
Sourcepub fn entries(&self) -> Result<JsValue, Error>
pub fn entries(&self) -> Result<JsValue, Error>
Returns the balance as an array of [key, value] pairs.
Sourcepub fn to_string_js(&self) -> String
pub fn to_string_js(&self) -> String
Return the string representation of the balance.